@@ -7,10 +7,10 @@ from notecoin.okex.v5.types import CcyType
 from notecoin.okex.v5.utils import enum_to_str, iterable_to_str
 
 
-class AssetAPI(BaseClient):
+class AssetClient(BaseClient):
 
     def __init__(self, *args, **kwargs):
-        super(AssetAPI, self).__init__(*args, **kwargs)
+        super(AssetClient, self).__init__(*args, **kwargs)
 
     def deposit_address(self, ccy: Union[CcyType, str]):
         params = {}
