@@ -7,10 +7,10 @@ from notecoin.okex.v5.types import InstType
 from notecoin.okex.v5.utils import enum_to_str
 
 
-class PublicAPI(BaseClient):
+class PublicClient(BaseClient):
 
     def __init__(self, *args, **kwargs):
-        super(PublicAPI, self).__init__(*args, **kwargs)
+        super(PublicClient, self).__init__(*args, **kwargs)
 
     def instruments(self, instType: Union[InstType, str], uly: Optional[str] = None, instId: Optional[str] = None):
         params = {}
