@@ -4,10 +4,10 @@ from notecoin.okex.v5.client.base import BaseClient
 from notecoin.okex.v5.consts import *
 
 
-class SystemAPI(BaseClient):
+class SystemClient(BaseClient):
 
     def __init__(self, *args, **kwargs):
-        super(SystemAPI, self).__init__(*args, **kwargs)
+        super(SystemClient, self).__init__(*args, **kwargs)
 
     def status(self, state: Optional[str] = None):
         params = {}
