@@ -7,56 +7,56 @@ from notecoin.okex.v5.utils import enum_to_str
 
 
 class Order(object):
-    def __init__(self, instId: str, tdMode: Union[TdMode, str], ordType: Union[OrderType, str],
+    def __init__(self, inst_id: str, td_mode: Union[TdMode, str], ord_type: Union[OrderType, str],
                  sz: Union[float, int, str], ccy: Optional[Union[CcyType, str]] = None,
-                 clOrdId: Optional[str] = None, tag: Optional[str] = None,
-                 posSide: Optional[Union[PosSide, str]] = None,
-                 reduceOnly: Optional[Union[str, bool]] = None,
-                 tgtCcy: Optional[Union[TrgCCY, str]] = None) -> None:
-        super().__init__()
-        self.instId = instId
-        self.tdMode = tdMode
-        self.ordType = ordType
+                 cl_ord_id: Optional[str] = None, tag: Optional[str] = None,
+                 pos_side: Optional[Union[PosSide, str]] = None,
+                 reduce_only: Optional[Union[str, bool]] = None,
+                 tgt_ccy: Optional[Union[TrgCCY, str]] = None) -> None:
+        super(Order, self).__init__()
+        self.instId = inst_id
+        self.tdMode = td_mode
+        self.ordType = ord_type
         self.sz = sz
         self.ccy = ccy
-        self.clOrdId = clOrdId
+        self.clOrdId = cl_ord_id
         self.tag = tag
-        self.posSide = posSide
-        self.reduceOnly = reduceOnly
-        self.tgtCcy = tgtCcy
+        self.posSide = pos_side
+        self.reduceOnly = reduce_only
+        self.tgtCcy = tgt_ccy
 
 
 class CancelOrder(object):
-    def __init__(self, instId: str, ordId: Optional[str] = None, clOrdId: Optional[str] = None) -> None:
-        super().__init__()
-        self.instId = instId
-        self.ordId = ordId
-        self.clOrdId = clOrdId
+    def __init__(self, inst_id: str, ord_id: Optional[str] = None, cl_ord_id: Optional[str] = None) -> None:
+        super(CancelOrder, self).__init__()
+        self.instId = inst_id
+        self.ordId = ord_id
+        self.clOrdId = cl_ord_id
 
 
-class TradeAPI(BaseClient):
+class TradeClient(BaseClient):
 
     def __init__(self, *args, **kwargs):
-        super(TradeAPI, self).__init__(*args, **kwargs)
+        super(TradeClient, self).__init__(*args, **kwargs)
 
-    def order(self, instId: str,
-              tdMode: Union[TdMode, str],
-              ordType: Union[OrderType, str],
+    def order(self, inst_id: str,
+              td_mode: Union[TdMode, str],
+              ord_type: Union[OrderType, str],
               sz: Union[float, int, str],
               ccy: Optional[Union[CcyType, str]] = None,
-              clOrdId: Optional[str] = None,
+              cl_ord_id: Optional[str] = None,
               tag: Optional[str] = None,
-              posSide: Optional[Union[PosSide, str]] = None,
+              pos_side: Optional[Union[PosSide, str]] = None,
               px: Optional[Union[float, int, str]] = None,
-              reduceOnly: Optional[Union[str, bool]] = None
+              reduce_only: Optional[Union[str, bool]] = None
               ) -> Dict:
         params = {}
-        if instId is not None:
-            params['instId'] = str(instId)
-        if tdMode is not None:
-            params['tdMode'] = enum_to_str(tdMode)
-        if ordType is not None:
-            params['ordType'] = enum_to_str(ordType)
+        if inst_id is not None:
+            params['instId'] = str(inst_id)
+        if td_mode is not None:
+            params['tdMode'] = enum_to_str(td_mode)
+        if ord_type is not None:
+            params['ordType'] = enum_to_str(ord_type)
         if sz is not None:
             params['sz'] = str(abs(sz))
             if sz >= 0:
@@ -65,22 +65,22 @@ class TradeAPI(BaseClient):
                 params['side'] = 'sell'
         if ccy is not None:
             params['ccy'] = enum_to_str(ccy)
-        if clOrdId is not None:
-            params['clOrdId'] = str(clOrdId)
+        if cl_ord_id is not None:
+            params['clOrdId'] = str(cl_ord_id)
         if tag is not None:
             params['tag'] = str(tag)
-        if posSide is not None:
-            params['posSide'] = enum_to_str(posSide)
+        if pos_side is not None:
+            params['posSide'] = enum_to_str(pos_side)
         if px is not None:
             params['px'] = str(px)
-        if reduceOnly is not None:
-            if isinstance(reduceOnly, bool):
-                if reduceOnly:
+        if reduce_only is not None:
+            if isinstance(reduce_only, bool):
+                if reduce_only:
                     params['reduceOnly'] = 'true'
                 else:
                     params['reduceOnly'] = 'false'
             else:
-                params['reduceOnly'] = str(reduceOnly)
+                params['reduceOnly'] = str(reduce_only)
         data = self._request_with_params(POST, ORDER, params)["data"]
 
         return data
@@ -132,15 +132,15 @@ class TradeAPI(BaseClient):
 
         return data
 
-    def cancel_order(self, instId: str, ordId: Optional[str] = None, clOrdId: Optional[str] = None):
+    def cancel_order(self, inst_id: str, ord_id: Optional[str] = None, cl_ord_id: Optional[str] = None):
         params = dict()
 
-        if instId is not None:
-            params['instId'] = str(instId)
-        if ordId is not None:
-            params['ordId'] = str(ordId)
-        if clOrdId is not None:
-            params['clOrdId'] = str(clOrdId)
+        if inst_id is not None:
+            params['instId'] = str(inst_id)
+        if ord_id is not None:
+            params['ordId'] = str(ord_id)
+        if cl_ord_id is not None:
+            params['clOrdId'] = str(cl_ord_id)
 
         data = self._request_with_params(POST, CANCEL_ORDER, params)["data"]
         return data
@@ -156,24 +156,24 @@ class TradeAPI(BaseClient):
         for order in orders_list:
             param = dict()
             if order.instId is not None:
-                params['instId'] = str(order.instId)
+                param["instId"] = str(order.instId)
             if order.ordId is not None:
-                params['ordId'] = str(order.ordId)
+                param["ordId"] = str(order.ordId)
             if order.clOrdId is not None:
-                params['clOrdId'] = str(order.clOrdId)
+                param["clOrdId"] = str(order.clOrdId)
             params.append(param)
 
         data = self._request_with_params(POST, CANCEL_BATCH_ORDERS, params)["data"]
         return data
 
-    def get_order(self, instId: str, ordId: Optional[str] = None, clOrdId: Optional[str] = None) -> Dict:
+    def get_order(self, inst_id: str, ord_id: Optional[str] = None, cl_ord_id: Optional[str] = None) -> Dict:
         params = {}
-        if instId is not None:
-            params['instId'] = str(instId)
-        if ordId is not None:
-            params['ordId'] = str(ordId)
-        if clOrdId is not None:
-            params['clOrdId'] = str(clOrdId)
+        if inst_id is not None:
+            params['instId'] = str(inst_id)
+        if ord_id is not None:
+            params['ordId'] = str(ord_id)
+        if cl_ord_id is not None:
+            params['clOrdId'] = str(cl_ord_id)
 
         data = self._request_with_params(GET, ORDER, params)["data"]
 
